@@ -2,7 +2,7 @@
 
 /* 
  * LDAPObject - wrapper around an LDAP* context
- * $Id: LDAPObject.c,v 1.69 2005/06/14 17:49:13 stroeder Exp $
+ * $Id: LDAPObject.c,v 1.74 2006/04/05 22:40:14 stroeder Exp $
  */
 
 #include "Python.h"
@@ -565,7 +565,7 @@ static int interaction ( unsigned flags,
 			 sasl_interact_t *interact,
 			 PyObject* SASLObject )
 {
-  const char *dflt = interact->defresult;
+/*  const char *dflt = interact->defresult; */
   PyObject *result;
   char *c_result;
   result = PyObject_CallMethod(SASLObject,
@@ -632,7 +632,7 @@ static PyObject*
 l_ldap_sasl_interactive_bind_s( LDAPObject* self, PyObject* args )
 {
     char *c_mechanism;
-    char *who, *cred;
+    char *who;
 
     PyObject *serverctrls = Py_None;
     PyObject *clientctrls = Py_None;
@@ -641,9 +641,8 @@ l_ldap_sasl_interactive_bind_s( LDAPObject* self, PyObject* args )
 
     PyObject       *SASLObject = NULL;
     PyObject *mechanism = NULL;
-    int msgid, version;
+    int msgid;
 
-    void *defaults;
     static unsigned sasl_flags = LDAP_SASL_QUIET;
 
     /* 
@@ -924,9 +923,9 @@ l_ldap_result3( LDAPObject* self, PyObject *args )
     	return LDAPerror( self->ldap, "ldap_result3" );
 
     if (res_type == 0) {
-	/* Polls return (None, None, None); timeouts raise an exception */
+	/* Polls return (None, None, None, None); timeouts raise an exception */
 	if (timeout == 0)
-		return Py_BuildValue("(OOO)", Py_None, Py_None, Py_None);
+		return Py_BuildValue("(OOOO)", Py_None, Py_None, Py_None, Py_None);
 	else
 		return LDAPerr(LDAP_TIMEOUT);
     }
@@ -954,12 +953,14 @@ l_ldap_result3( LDAPObject* self, PyObject *args )
 		e = err;
 	    } else
 		e = "ldap_parse_result";
+	    ldap_msgfree(msg);
 	    return LDAPerror( self->ldap, e );
 	}
 
         if (!(pyctrls = LDAPControls_to_List(serverctrls))) {
             int err = LDAP_NO_MEMORY;
             ldap_set_option(self->ldap, LDAP_OPT_ERROR_NUMBER, &err);
+	    ldap_msgfree(msg);
             return LDAPerror(self->ldap, "LDAPControls_to_List");
         }
         ldap_controls_free(serverctrls);
@@ -972,8 +973,16 @@ l_ldap_result3( LDAPObject* self, PyObject *args )
     if (pmsg == NULL) {
 	    retval = NULL;
     } else {
-        retval = Py_BuildValue("(OOiO)", result_str, pmsg, res_msgid,
-			       pyctrls ? pyctrls : PyList_New(0));
+	if (pyctrls != NULL) {
+        	retval = Py_BuildValue("(OOiO)", result_str, pmsg, res_msgid,
+				       pyctrls);
+	} else { 
+		PyObject *pNewList = PyList_New(0);
+        	retval = Py_BuildValue("(OOiO)", result_str, pmsg, res_msgid,
+				       pNewList);
+		Py_DECREF(pNewList);
+	}
+
 	if (pmsg != Py_None) {
         Py_DECREF(pmsg);
     }
@@ -1053,7 +1062,6 @@ l_ldap_search_ext( LDAPObject* self, PyObject* args )
 }	
 
 
-#if LDAP_VENDOR_VERSION>=20113
 /* ldap_whoami_s (available since OpenLDAP 2.1.13) */
 
 static PyObject*
@@ -1098,7 +1106,6 @@ l_ldap_whoami_s( LDAPObject* self, PyObject* args )
 
     return result;
 }
-#endif
 
 #ifdef HAVE_TLS
 /* ldap_start_tls_s */
@@ -1155,8 +1162,6 @@ l_ldap_get_option(PyObject* self, PyObject *args)
 
 /* ldap_passwd */
 
-#if LDAP_VENDOR_VERSION>=20100
-
 static PyObject *
 l_ldap_passwd( LDAPObject* self, PyObject *args )
 {
@@ -1208,8 +1213,6 @@ l_ldap_passwd( LDAPObject* self, PyObject *args )
     return PyInt_FromLong( msgid );
 }
 
-#endif
-
 /* methods */
 
 static PyMethodDef methods[] = {
@@ -1229,12 +1232,8 @@ static PyMethodDef methods[] = {
 #ifdef HAVE_TLS
     {"start_tls_s",	(PyCFunction)l_ldap_start_tls_s,	METH_VARARGS },
 #endif
-#if LDAP_VENDOR_VERSION>=20113
     {"whoami_s",	(PyCFunction)l_ldap_whoami_s,	        METH_VARARGS },
-#endif
-#if LDAP_VENDOR_VERSION>=20100
     {"passwd",	        (PyCFunction)l_ldap_passwd,	        METH_VARARGS },
-#endif
     {"set_option",	(PyCFunction)l_ldap_set_option,		METH_VARARGS },
     {"get_option",	(PyCFunction)l_ldap_get_option,		METH_VARARGS },
 #if defined(FILENO_SUPPORTED)
